#!/usr/bin/env python3

import os.path
import json
# from simple_term_menu import TerminalMenu
import subprocess
import os.path
from os import path

# install create react app

# check if git cz is installed
# check if git flow is installed

ci_file = """.shared:
  image: node:lts-alpine

  stages:
    - quality

  linter:
    stage: quality
    extends:
      - .shared
    script:
      - npm run lint
"""

prettier = """{ 
  "semi": false, 
  "singleQuote": true, 
  "endOfLine":"auto" 
}
"""

vscode_settings = """{
  "editor.defaultFormatter": "esbenp.prettier-vscode",
  "editor.codeActionsOnSave": { "source.fixAll.eslint": true }, 
  "editor.formatOnSave": true, 
  "eslint.alwaysShowStatus": true, 
  "files.autoSave": "onFocusChange"
}
"""

def install_husky():
  os.system("npm install --silent --save-dev husky")
  os.system("npx husky install")
  os.system("npm set-script prepare 'husky install'")
  
def husky_config():
  os.system("npm install --silent --save-dev husky")
  os.system("npx husky install")
  os.system("npm set-script prepare 'husky install'")
  
def cz_config():
  os.system("npm install --silent --save-dev commitlint commitlint-config-azot")
  os.system("npx commitizen init cz-emoji-azot --save-dev --save-exact --force")
  os.system("echo \"module.exports = {extends: ['azot']}\" > .commitlintrc.js")
  os.system("npx husky add .husky/commit-msg 'npx --no-install -s commitlint --edit \"$1\"'")
  
  
def vscode_config():
  try:
    os.mkdir(".vscode")
  except:
    print ("folder .vscode already exists")
  f = open(".vscode/settings.json", "w")
  f.write(vscode_settings)
  f.close()
  
def prettier_config():
  os.system("npm install --silent --save --legacy-peer-deps")
  os.system("npm install --silent --save-dev eslint prettier eslint-config-prettier eslint-plugin-prettier")
  f = open(".prettierrc.json", "w")
  f.write(prettier)
  f.close()
  
def eslint_config():
  os.system("npx eslint --init")
  f = open(".eslintrc.json", "r")
  conf = json.load(f)
  f.close()
  conf["extends"].append("plugin:prettier/recommended")
  f = open(".eslintrc.json", "w")
  json.dump(conf, f, indent=2)
  f.close()
  os.system("npm set-script lint 'eslint .'")
  os.system("npx husky add .husky/commit-msg 'npm -s run lint'")
  
  
def style_install():
  print("executing from", subprocess.run(['echo', '$0'], stdout=subprocess.PIPE).stdout.decode('utf-8'))

def menu(description, choices = []):
  print(description)
  return TerminalMenu(choices).show()

def gitflow_config():
  if os.system("git flow version") != 0:
    print("make sure to have already installed gitflow")
    exit(1)
  if not path.exists('.git'):
    os.system("git init")
  os.system("git flow init")
  

def ci_config():
  f = open(".gitlab-ci.yml", "w")
  f.write(ci_file)
  f.close()
  
  
def be_pretty_config():
  os.system("npm install --silent --save-dev prettier be-pretty")
  os.system("npm set-script pretty 'be-pretty formatAll'")
  os.system("npx husky add .husky/commit-msg 'npm -s run pretty'")
  

def display_install(function, title):
  # print("🛵 Installing", title, end="\r")
  function()
  print("✅ Installed", title)

def main():
  display_install(gitflow_config, "gitflow")
  display_install(vscode_config, "vscode configuration")
  display_install(prettier_config, "prettier configuration")
  display_install(husky_config, "husky configuration")
  display_install(be_pretty_config, "be pretty configuration")
  display_install(cz_config, "commitizen configuration")
  display_install(eslint_config, "eslint configuration")
  display_install(ci_config, "gitlab ci configuration")
  # project = menu("Choose a project type:", ["Javascript"])
  # switcher = {
  #   0: javascript,
  # }
  # switcher.get(project, lambda: "Invalid type")()


if __name__ == "__main__":
  main()